@@ -5,8 +5,8 @@
 
 ;; Maintainer: James Cherti
 ;; Original Author: steckerhalter
-;; Package-Version: 20250915.131
-;; Package-Revision: fe0d6c611ec9
+;; Package-Version: 20251103.1434
+;; Package-Revision: 98b53d3dbf84
 ;; URL: https://github.com/jamescherti/quick-fasd.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "25.1"))
@@ -261,7 +261,7 @@ directories."
 
 ;;;###autoload
 (define-minor-mode quick-fasd-mode
-  "Toggle `quick-fasd-mode' mode globally."
+  "Integration for the command-line tool `fasd'."
   :global t
   :group 'quick-fasd
   :lighter quick-fasd-mode-lighter
